@@ -105,7 +105,7 @@ for (i in 1:20) {
 dansari <- function(x, m ,n)
 {
     .C("dansari", as.integer(length(x)), d = as.double(x), as.integer(m),
-       as.integer(n), PACKAGE="ctest")$d
+       as.integer(n), PACKAGE="exactRankTests")$d
 }
 
 # Ansari-Bradley
